@@ -50,10 +50,12 @@ extern SEXP Descriptor__nested_type(SEXP, SEXP);
 extern SEXP Descriptor__nested_type_count(SEXP);
 extern SEXP Descriptor__readASCIIFromConnection(SEXP, SEXP, SEXP);
 extern SEXP Descriptor__readASCIIFromString(SEXP, SEXP, SEXP);
+extern SEXP Descriptor__readJSONFromConnection(SEXP, SEXP);
+extern SEXP Descriptor__readJSONFromString(SEXP, SEXP);
 extern SEXP Descriptor__readMessageFromConnection(SEXP, SEXP);
 extern SEXP Descriptor__readMessageFromFile(SEXP, SEXP);
 extern SEXP Descriptor__readMessageFromRawVector(SEXP, SEXP);
-extern SEXP Descriptor_getField(SEXP, SEXP, SEXP);
+extern SEXP Descriptor_getField(SEXP, SEXP);
 extern SEXP do_dollar_Descriptor(SEXP, SEXP);
 extern SEXP EnumDescriptor__as_character(SEXP);
 extern SEXP EnumDescriptor__as_list(SEXP);
@@ -115,6 +117,7 @@ extern SEXP has_enum_name(SEXP, SEXP);
 extern SEXP identical_messages(SEXP, SEXP);
 extern SEXP Message__add_values(SEXP, SEXP, SEXP);
 extern SEXP Message__as_character(SEXP);
+extern SEXP Message__as_json(SEXP, SEXP, SEXP);
 extern SEXP Message__as_list(SEXP);
 extern SEXP Message__bytesize(SEXP);
 extern SEXP Message__clear(SEXP);
@@ -133,6 +136,7 @@ extern SEXP Message__is_initialized(SEXP);
 extern SEXP Message__length(SEXP);
 extern SEXP Message__merge(SEXP, SEXP);
 extern SEXP Message__num_extensions(SEXP);
+extern SEXP Message__print_text_format(SEXP);
 extern SEXP Message__serialize_to_file(SEXP, SEXP);
 extern SEXP Message__set_field_size(SEXP, SEXP, SEXP);
 extern SEXP Message__set_field_values(SEXP, SEXP, SEXP, SEXP);
@@ -146,6 +150,7 @@ extern SEXP MethodDescriptor__output_type(SEXP);
 extern SEXP newProtocolBufferLookup(SEXP);
 extern SEXP newProtoMessage(SEXP);
 extern SEXP readProtoFiles_cpp(SEXP, SEXP);
+extern SEXP resetDescriptorPool_cpp();
 extern SEXP ServiceDescriptor__as_character(SEXP);
 extern SEXP ServiceDescriptor__as_list(SEXP);
 extern SEXP ServiceDescriptor__as_Message(SEXP);
@@ -205,10 +210,12 @@ static const R_CallMethodDef CallEntries[] = {
     {"Descriptor__nested_type_count",            (DL_FUNC) &Descriptor__nested_type_count,             1},
     {"Descriptor__readASCIIFromConnection",      (DL_FUNC) &Descriptor__readASCIIFromConnection,       3},
     {"Descriptor__readASCIIFromString",          (DL_FUNC) &Descriptor__readASCIIFromString,           3},
+    {"Descriptor__readJSONFromConnection",       (DL_FUNC) &Descriptor__readJSONFromConnection,        2},
+    {"Descriptor__readJSONFromString",           (DL_FUNC) &Descriptor__readJSONFromString,            2},
     {"Descriptor__readMessageFromConnection",    (DL_FUNC) &Descriptor__readMessageFromConnection,     2},
     {"Descriptor__readMessageFromFile",          (DL_FUNC) &Descriptor__readMessageFromFile,           2},
     {"Descriptor__readMessageFromRawVector",     (DL_FUNC) &Descriptor__readMessageFromRawVector,      2},
-    {"Descriptor_getField",                      (DL_FUNC) &Descriptor_getField,                       3},
+    {"Descriptor_getField",                      (DL_FUNC) &Descriptor_getField,                       2},
     {"do_dollar_Descriptor",                     (DL_FUNC) &do_dollar_Descriptor,                      2},
     {"EnumDescriptor__as_character",             (DL_FUNC) &EnumDescriptor__as_character,              1},
     {"EnumDescriptor__as_list",                  (DL_FUNC) &EnumDescriptor__as_list,                   1},
@@ -270,6 +277,7 @@ static const R_CallMethodDef CallEntries[] = {
     {"identical_messages",                       (DL_FUNC) &identical_messages,                        2},
     {"Message__add_values",                      (DL_FUNC) &Message__add_values,                       3},
     {"Message__as_character",                    (DL_FUNC) &Message__as_character,                     1},
+    {"Message__as_json",                         (DL_FUNC) &Message__as_json,                          3},
     {"Message__as_list",                         (DL_FUNC) &Message__as_list,                          1},
     {"Message__bytesize",                        (DL_FUNC) &Message__bytesize,                         1},
     {"Message__clear",                           (DL_FUNC) &Message__clear,                            1},
@@ -289,6 +297,7 @@ static const R_CallMethodDef CallEntries[] = {
     {"Message__merge",                           (DL_FUNC) &Message__merge,                            2},
     {"Message__num_extensions",                  (DL_FUNC) &Message__num_extensions,                   1},
     {"Message__serialize_to_file",               (DL_FUNC) &Message__serialize_to_file,                2},
+    {"Message__print_text_format",               (DL_FUNC) &Message__print_text_format,                1},
     {"Message__set_field_size",                  (DL_FUNC) &Message__set_field_size,                   3},
     {"Message__set_field_values",                (DL_FUNC) &Message__set_field_values,                 4},
     {"Message__swap",                            (DL_FUNC) &Message__swap,                             4},
@@ -301,6 +310,7 @@ static const R_CallMethodDef CallEntries[] = {
     {"newProtocolBufferLookup",                  (DL_FUNC) &newProtocolBufferLookup,                   1},
     {"newProtoMessage",                          (DL_FUNC) &newProtoMessage,                           1},
     {"readProtoFiles_cpp",                       (DL_FUNC) &readProtoFiles_cpp,                        2},
+    {"resetDescriptorPool_cpp",                  (DL_FUNC) &resetDescriptorPool_cpp,                   0},
     {"ServiceDescriptor__as_character",          (DL_FUNC) &ServiceDescriptor__as_character,           1},
     {"ServiceDescriptor__as_list",               (DL_FUNC) &ServiceDescriptor__as_list,                1},
     {"ServiceDescriptor__as_Message",            (DL_FUNC) &ServiceDescriptor__as_Message,             1},
@@ -341,3 +351,7 @@ void R_init_RProtoBuf(DllInfo *dll) {
     R_registerRoutines(dll, NULL, CallEntries, NULL, NULL);
     R_useDynamicSymbols(dll, FALSE);
 }
+
+void R_unload_RProtoBuf(DllInfo* dll) {
+    resetDescriptorPool_cpp();
+}
